@@ -2,8 +2,11 @@
 
 # External command, intended to be called with meson.add_dist_script() in meson.build
 
-#                        argv[1]          argv[2]
-# extra-dist-cmd.py <root_source_dir> <root_build_dir>
+#                        argv[1]         argv[2]        argv[3:]
+# extra-dist-cmd.py <root_source_dir> <root_build_dir> <no_dist>...
+
+# <no_dist> Zero or more names (relative to MESON_PROJECT_DIST_ROOT)
+#           of files and directories that shall not be distributed.
 
 # Meson does not preserve timestamps on distributed files.
 # But this script preserves the timestamps on libstdc++.tag.
@@ -32,10 +35,21 @@ project_dist_root = os.getenv('MESON_PROJECT_DIST_ROOT', os.getenv('MESON_DIST_R
 logfilename = os.path.join(project_dist_root, 'ChangeLog')
 with open(logfilename, mode='w', encoding='utf-8') as logfile:
   result = subprocess.run(cmd, stdout=logfile)
+  if result.returncode:
+    sys.exit(result.returncode)
 
 # Distribute the libstdc++.tag file in addition to the files in the local git clone.
 # shutil.copy2() copies timestamps and some other file metadata.
 shutil.copy2(os.path.join(root_build_dir, 'libstdc++.tag'),
              os.path.join(project_dist_root, 'doctags'))
 
-sys.exit(result.returncode)
+# Remove specified files and directories from the MESON_PROJECT_DIST_ROOT directory.
+for rel_path in sys.argv[3:]:
+  abs_path = os.path.join(project_dist_root, rel_path)
+  if os.path.isfile(abs_path):
+    os.remove(abs_path)
+  elif os.path.isdir(abs_path):
+    shutil.rmtree(abs_path, ignore_errors=True)
+  else:
+    # Ignore non-existent files and directories.
+    print('--- Info:', abs_path, 'not found, not removed.')
